# coding: utf-8

"""
    Abstract API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CollectionAncestors(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'datetime',
        'description': 'str',
        'description_short': 'str',
        'display_name': 'str',
        'id': 'str',
        'key_value': 'object',
        'modified_at': 'datetime',
        'published': 'bool'
    }

    attribute_map = {
        'created_at': 'created_at',
        'description': 'description',
        'description_short': 'description_short',
        'display_name': 'display_name',
        'id': 'id',
        'key_value': 'key_value',
        'modified_at': 'modified_at',
        'published': 'published'
    }

    def __init__(self, created_at=None, description=None, description_short=None, display_name=None, id=None, key_value=None, modified_at=None, published=None):  # noqa: E501
        """CollectionAncestors - a model defined in Swagger"""  # noqa: E501

        self._created_at = None
        self._description = None
        self._description_short = None
        self._display_name = None
        self._id = None
        self._key_value = None
        self._modified_at = None
        self._published = None
        self.discriminator = None

        if created_at is not None:
            self.created_at = created_at
        if description is not None:
            self.description = description
        if description_short is not None:
            self.description_short = description_short
        if display_name is not None:
            self.display_name = display_name
        self.id = id
        if key_value is not None:
            self.key_value = key_value
        if modified_at is not None:
            self.modified_at = modified_at
        if published is not None:
            self.published = published

    @property
    def created_at(self):
        """Gets the created_at of this CollectionAncestors.  # noqa: E501


        :return: The created_at of this CollectionAncestors.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this CollectionAncestors.


        :param created_at: The created_at of this CollectionAncestors.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def description(self):
        """Gets the description of this CollectionAncestors.  # noqa: E501


        :return: The description of this CollectionAncestors.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CollectionAncestors.


        :param description: The description of this CollectionAncestors.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def description_short(self):
        """Gets the description_short of this CollectionAncestors.  # noqa: E501


        :return: The description_short of this CollectionAncestors.  # noqa: E501
        :rtype: str
        """
        return self._description_short

    @description_short.setter
    def description_short(self, description_short):
        """Sets the description_short of this CollectionAncestors.


        :param description_short: The description_short of this CollectionAncestors.  # noqa: E501
        :type: str
        """

        self._description_short = description_short

    @property
    def display_name(self):
        """Gets the display_name of this CollectionAncestors.  # noqa: E501


        :return: The display_name of this CollectionAncestors.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this CollectionAncestors.


        :param display_name: The display_name of this CollectionAncestors.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def id(self):
        """Gets the id of this CollectionAncestors.  # noqa: E501


        :return: The id of this CollectionAncestors.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CollectionAncestors.


        :param id: The id of this CollectionAncestors.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def key_value(self):
        """Gets the key_value of this CollectionAncestors.  # noqa: E501


        :return: The key_value of this CollectionAncestors.  # noqa: E501
        :rtype: object
        """
        return self._key_value

    @key_value.setter
    def key_value(self, key_value):
        """Sets the key_value of this CollectionAncestors.


        :param key_value: The key_value of this CollectionAncestors.  # noqa: E501
        :type: object
        """

        self._key_value = key_value

    @property
    def modified_at(self):
        """Gets the modified_at of this CollectionAncestors.  # noqa: E501


        :return: The modified_at of this CollectionAncestors.  # noqa: E501
        :rtype: datetime
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this CollectionAncestors.


        :param modified_at: The modified_at of this CollectionAncestors.  # noqa: E501
        :type: datetime
        """

        self._modified_at = modified_at

    @property
    def published(self):
        """Gets the published of this CollectionAncestors.  # noqa: E501


        :return: The published of this CollectionAncestors.  # noqa: E501
        :rtype: bool
        """
        return self._published

    @published.setter
    def published(self, published):
        """Sets the published of this CollectionAncestors.


        :param published: The published of this CollectionAncestors.  # noqa: E501
        :type: bool
        """

        self._published = published

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CollectionAncestors):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
