# coding: utf-8

"""
    Abstract API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ApiusersProfile(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'expertise': 'str',
        'subscribed': 'bool'
    }

    attribute_map = {
        'expertise': 'expertise',
        'subscribed': 'subscribed'
    }

    def __init__(self, expertise='null', subscribed=True):  # noqa: E501
        """ApiusersProfile - a model defined in Swagger"""  # noqa: E501

        self._expertise = None
        self._subscribed = None
        self.discriminator = None

        if expertise is not None:
            self.expertise = expertise
        if subscribed is not None:
            self.subscribed = subscribed

    @property
    def expertise(self):
        """Gets the expertise of this ApiusersProfile.  # noqa: E501


        :return: The expertise of this ApiusersProfile.  # noqa: E501
        :rtype: str
        """
        return self._expertise

    @expertise.setter
    def expertise(self, expertise):
        """Sets the expertise of this ApiusersProfile.


        :param expertise: The expertise of this ApiusersProfile.  # noqa: E501
        :type: str
        """
        allowed_values = ["hobbyist", "professional", "student"]  # noqa: E501
        if expertise not in allowed_values:
            raise ValueError(
                "Invalid value for `expertise` ({0}), must be one of {1}"  # noqa: E501
                .format(expertise, allowed_values)
            )

        self._expertise = expertise

    @property
    def subscribed(self):
        """Gets the subscribed of this ApiusersProfile.  # noqa: E501


        :return: The subscribed of this ApiusersProfile.  # noqa: E501
        :rtype: bool
        """
        return self._subscribed

    @subscribed.setter
    def subscribed(self, subscribed):
        """Sets the subscribed of this ApiusersProfile.


        :param subscribed: The subscribed of this ApiusersProfile.  # noqa: E501
        :type: bool
        """

        self._subscribed = subscribed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiusersProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
