# coding: utf-8

"""
    Abstract API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from enigma.swagger_client.models.apidatasets_dependencies import ApidatasetsDependencies  # noqa: F401,E501
from enigma.swagger_client.models.collection_ancestors import CollectionAncestors  # noqa: F401,E501
from enigma.swagger_client.models.collection_highlights import CollectionHighlights  # noqa: F401,E501
from enigma.swagger_client.models.dataset_current_snapshot_ingest_status import DatasetCurrentSnapshotIngestStatus  # noqa: F401,E501
from enigma.swagger_client.models.dataset_current_snapshot_table_rows import DatasetCurrentSnapshotTableRows  # noqa: F401,E501
from enigma.swagger_client.models.snapshot_field import SnapshotField  # noqa: F401,E501


class Snapshot(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'datetime',
        'dataset': 'CollectionAncestors',
        'end_date': 'datetime',
        'fields': 'list[SnapshotField]',
        'highlights': 'list[CollectionHighlights]',
        'id': 'str',
        'ingest_schema': 'list[object]',
        'ingest_status': 'DatasetCurrentSnapshotIngestStatus',
        'ingest_url': 'str',
        'parent_snapshot': 'ApidatasetsDependencies',
        'record_start_date': 'datetime',
        'row_count': 'int',
        'size': 'int',
        'start_date': 'datetime',
        'stats': 'object',
        'table_rows': 'DatasetCurrentSnapshotTableRows'
    }

    attribute_map = {
        'created_at': 'created_at',
        'dataset': 'dataset',
        'end_date': 'end_date',
        'fields': 'fields',
        'highlights': 'highlights',
        'id': 'id',
        'ingest_schema': 'ingest_schema',
        'ingest_status': 'ingest_status',
        'ingest_url': 'ingest_url',
        'parent_snapshot': 'parent_snapshot',
        'record_start_date': 'record_start_date',
        'row_count': 'row_count',
        'size': 'size',
        'start_date': 'start_date',
        'stats': 'stats',
        'table_rows': 'table_rows'
    }

    def __init__(self, created_at=None, dataset=None, end_date=None, fields=None, highlights=None, id=None, ingest_schema=None, ingest_status=None, ingest_url=None, parent_snapshot=None, record_start_date=None, row_count=None, size=None, start_date=None, stats=None, table_rows=None):  # noqa: E501
        """Snapshot - a model defined in Swagger"""  # noqa: E501

        self._created_at = None
        self._dataset = None
        self._end_date = None
        self._fields = None
        self._highlights = None
        self._id = None
        self._ingest_schema = None
        self._ingest_status = None
        self._ingest_url = None
        self._parent_snapshot = None
        self._record_start_date = None
        self._row_count = None
        self._size = None
        self._start_date = None
        self._stats = None
        self._table_rows = None
        self.discriminator = None

        if created_at is not None:
            self.created_at = created_at
        if dataset is not None:
            self.dataset = dataset
        if end_date is not None:
            self.end_date = end_date
        if fields is not None:
            self.fields = fields
        if highlights is not None:
            self.highlights = highlights
        if id is not None:
            self.id = id
        if ingest_schema is not None:
            self.ingest_schema = ingest_schema
        if ingest_status is not None:
            self.ingest_status = ingest_status
        if ingest_url is not None:
            self.ingest_url = ingest_url
        if parent_snapshot is not None:
            self.parent_snapshot = parent_snapshot
        if record_start_date is not None:
            self.record_start_date = record_start_date
        if row_count is not None:
            self.row_count = row_count
        if size is not None:
            self.size = size
        if start_date is not None:
            self.start_date = start_date
        if stats is not None:
            self.stats = stats
        if table_rows is not None:
            self.table_rows = table_rows

    @property
    def created_at(self):
        """Gets the created_at of this Snapshot.  # noqa: E501


        :return: The created_at of this Snapshot.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Snapshot.


        :param created_at: The created_at of this Snapshot.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def dataset(self):
        """Gets the dataset of this Snapshot.  # noqa: E501


        :return: The dataset of this Snapshot.  # noqa: E501
        :rtype: CollectionAncestors
        """
        return self._dataset

    @dataset.setter
    def dataset(self, dataset):
        """Sets the dataset of this Snapshot.


        :param dataset: The dataset of this Snapshot.  # noqa: E501
        :type: CollectionAncestors
        """

        self._dataset = dataset

    @property
    def end_date(self):
        """Gets the end_date of this Snapshot.  # noqa: E501


        :return: The end_date of this Snapshot.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this Snapshot.


        :param end_date: The end_date of this Snapshot.  # noqa: E501
        :type: datetime
        """

        self._end_date = end_date

    @property
    def fields(self):
        """Gets the fields of this Snapshot.  # noqa: E501


        :return: The fields of this Snapshot.  # noqa: E501
        :rtype: list[SnapshotField]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this Snapshot.


        :param fields: The fields of this Snapshot.  # noqa: E501
        :type: list[SnapshotField]
        """

        self._fields = fields

    @property
    def highlights(self):
        """Gets the highlights of this Snapshot.  # noqa: E501


        :return: The highlights of this Snapshot.  # noqa: E501
        :rtype: list[CollectionHighlights]
        """
        return self._highlights

    @highlights.setter
    def highlights(self, highlights):
        """Sets the highlights of this Snapshot.


        :param highlights: The highlights of this Snapshot.  # noqa: E501
        :type: list[CollectionHighlights]
        """

        self._highlights = highlights

    @property
    def id(self):
        """Gets the id of this Snapshot.  # noqa: E501


        :return: The id of this Snapshot.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Snapshot.


        :param id: The id of this Snapshot.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def ingest_schema(self):
        """Gets the ingest_schema of this Snapshot.  # noqa: E501


        :return: The ingest_schema of this Snapshot.  # noqa: E501
        :rtype: list[object]
        """
        return self._ingest_schema

    @ingest_schema.setter
    def ingest_schema(self, ingest_schema):
        """Sets the ingest_schema of this Snapshot.


        :param ingest_schema: The ingest_schema of this Snapshot.  # noqa: E501
        :type: list[object]
        """

        self._ingest_schema = ingest_schema

    @property
    def ingest_status(self):
        """Gets the ingest_status of this Snapshot.  # noqa: E501


        :return: The ingest_status of this Snapshot.  # noqa: E501
        :rtype: DatasetCurrentSnapshotIngestStatus
        """
        return self._ingest_status

    @ingest_status.setter
    def ingest_status(self, ingest_status):
        """Sets the ingest_status of this Snapshot.


        :param ingest_status: The ingest_status of this Snapshot.  # noqa: E501
        :type: DatasetCurrentSnapshotIngestStatus
        """

        self._ingest_status = ingest_status

    @property
    def ingest_url(self):
        """Gets the ingest_url of this Snapshot.  # noqa: E501


        :return: The ingest_url of this Snapshot.  # noqa: E501
        :rtype: str
        """
        return self._ingest_url

    @ingest_url.setter
    def ingest_url(self, ingest_url):
        """Sets the ingest_url of this Snapshot.


        :param ingest_url: The ingest_url of this Snapshot.  # noqa: E501
        :type: str
        """

        self._ingest_url = ingest_url

    @property
    def parent_snapshot(self):
        """Gets the parent_snapshot of this Snapshot.  # noqa: E501


        :return: The parent_snapshot of this Snapshot.  # noqa: E501
        :rtype: ApidatasetsDependencies
        """
        return self._parent_snapshot

    @parent_snapshot.setter
    def parent_snapshot(self, parent_snapshot):
        """Sets the parent_snapshot of this Snapshot.


        :param parent_snapshot: The parent_snapshot of this Snapshot.  # noqa: E501
        :type: ApidatasetsDependencies
        """

        self._parent_snapshot = parent_snapshot

    @property
    def record_start_date(self):
        """Gets the record_start_date of this Snapshot.  # noqa: E501


        :return: The record_start_date of this Snapshot.  # noqa: E501
        :rtype: datetime
        """
        return self._record_start_date

    @record_start_date.setter
    def record_start_date(self, record_start_date):
        """Sets the record_start_date of this Snapshot.


        :param record_start_date: The record_start_date of this Snapshot.  # noqa: E501
        :type: datetime
        """

        self._record_start_date = record_start_date

    @property
    def row_count(self):
        """Gets the row_count of this Snapshot.  # noqa: E501


        :return: The row_count of this Snapshot.  # noqa: E501
        :rtype: int
        """
        return self._row_count

    @row_count.setter
    def row_count(self, row_count):
        """Sets the row_count of this Snapshot.


        :param row_count: The row_count of this Snapshot.  # noqa: E501
        :type: int
        """

        self._row_count = row_count

    @property
    def size(self):
        """Gets the size of this Snapshot.  # noqa: E501


        :return: The size of this Snapshot.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this Snapshot.


        :param size: The size of this Snapshot.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def start_date(self):
        """Gets the start_date of this Snapshot.  # noqa: E501


        :return: The start_date of this Snapshot.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Snapshot.


        :param start_date: The start_date of this Snapshot.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def stats(self):
        """Gets the stats of this Snapshot.  # noqa: E501


        :return: The stats of this Snapshot.  # noqa: E501
        :rtype: object
        """
        return self._stats

    @stats.setter
    def stats(self, stats):
        """Sets the stats of this Snapshot.


        :param stats: The stats of this Snapshot.  # noqa: E501
        :type: object
        """

        self._stats = stats

    @property
    def table_rows(self):
        """Gets the table_rows of this Snapshot.  # noqa: E501


        :return: The table_rows of this Snapshot.  # noqa: E501
        :rtype: DatasetCurrentSnapshotTableRows
        """
        return self._table_rows

    @table_rows.setter
    def table_rows(self, table_rows):
        """Sets the table_rows of this Snapshot.


        :param table_rows: The table_rows of this Snapshot.  # noqa: E501
        :type: DatasetCurrentSnapshotTableRows
        """

        self._table_rows = table_rows

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Snapshot):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
