# coding: utf-8

"""
    Abstract API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from enigma.swagger_client.models.apidatasets_dependencies import ApidatasetsDependencies  # noqa: F401,E501
from enigma.swagger_client.models.apidatasetsdataset_idsnapshotssnapshot_id_fields import ApidatasetsdatasetIdsnapshotssnapshotIdFields  # noqa: F401,E501


class Body9(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_date': 'datetime',
        'fields': 'list[ApidatasetsdatasetIdsnapshotssnapshotIdFields]',
        'id': 'str',
        'parent_snapshot': 'ApidatasetsDependencies',
        'record_start_date': 'datetime',
        'start_date': 'datetime'
    }

    attribute_map = {
        'end_date': 'end_date',
        'fields': 'fields',
        'id': 'id',
        'parent_snapshot': 'parent_snapshot',
        'record_start_date': 'record_start_date',
        'start_date': 'start_date'
    }

    def __init__(self, end_date=None, fields=None, id=None, parent_snapshot=None, record_start_date=None, start_date=None):  # noqa: E501
        """Body9 - a model defined in Swagger"""  # noqa: E501

        self._end_date = None
        self._fields = None
        self._id = None
        self._parent_snapshot = None
        self._record_start_date = None
        self._start_date = None
        self.discriminator = None

        if end_date is not None:
            self.end_date = end_date
        if fields is not None:
            self.fields = fields
        if id is not None:
            self.id = id
        if parent_snapshot is not None:
            self.parent_snapshot = parent_snapshot
        if record_start_date is not None:
            self.record_start_date = record_start_date
        if start_date is not None:
            self.start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this Body9.  # noqa: E501


        :return: The end_date of this Body9.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this Body9.


        :param end_date: The end_date of this Body9.  # noqa: E501
        :type: datetime
        """

        self._end_date = end_date

    @property
    def fields(self):
        """Gets the fields of this Body9.  # noqa: E501


        :return: The fields of this Body9.  # noqa: E501
        :rtype: list[ApidatasetsdatasetIdsnapshotssnapshotIdFields]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this Body9.


        :param fields: The fields of this Body9.  # noqa: E501
        :type: list[ApidatasetsdatasetIdsnapshotssnapshotIdFields]
        """

        self._fields = fields

    @property
    def id(self):
        """Gets the id of this Body9.  # noqa: E501


        :return: The id of this Body9.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Body9.


        :param id: The id of this Body9.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def parent_snapshot(self):
        """Gets the parent_snapshot of this Body9.  # noqa: E501


        :return: The parent_snapshot of this Body9.  # noqa: E501
        :rtype: ApidatasetsDependencies
        """
        return self._parent_snapshot

    @parent_snapshot.setter
    def parent_snapshot(self, parent_snapshot):
        """Sets the parent_snapshot of this Body9.


        :param parent_snapshot: The parent_snapshot of this Body9.  # noqa: E501
        :type: ApidatasetsDependencies
        """

        self._parent_snapshot = parent_snapshot

    @property
    def record_start_date(self):
        """Gets the record_start_date of this Body9.  # noqa: E501


        :return: The record_start_date of this Body9.  # noqa: E501
        :rtype: datetime
        """
        return self._record_start_date

    @record_start_date.setter
    def record_start_date(self, record_start_date):
        """Sets the record_start_date of this Body9.


        :param record_start_date: The record_start_date of this Body9.  # noqa: E501
        :type: datetime
        """

        self._record_start_date = record_start_date

    @property
    def start_date(self):
        """Gets the start_date of this Body9.  # noqa: E501


        :return: The start_date of this Body9.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Body9.


        :param start_date: The start_date of this Body9.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Body9):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
