# coding: utf-8

"""
    Enigma Public SDK

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import os
from setuptools import setup, find_packages  # noqa: H301

NAME = "enigma-sdk"
VERSION = "1.0.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, 'README.rst'), encoding='utf-8') as f:
    readme = f.read()

setup(
    name=NAME,
    version=VERSION,
    description="Enigma Public SDK",
    url="https://public.enigma.com/",
    author="Enigma",
    author_email="public-support@enigma.com",
    keywords='enigma public data api sdk',
    project_urls={
        'Documentation': 'http://docs.enigma.com/public/public_v20_sdk_about.html',
    },
    packages=find_packages(),
    install_requires=REQUIRES,
    python_requires='~=3.4',
    include_package_data=True,
    long_description=readme,
    long_description_content_type='text/x-rst',
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
)
